==> qore-0.8.12.2.tar.bz2: qore-0.8.12.2/docs/lang/html/search/variables_6f.js <==
var searchData=
[
  ['o_5faccmode',['O_ACCMODE',['../group__file__open__constants.html#ga8e48617453f7fd321bcceee8816bf23d',1,'Qore']]],
  ['o_5fappend',['O_APPEND',['../group__file__open__constants.html#gab47c6691139c37e08761a808d16ede1d',1,'Qore']]],
  ['o_5fcreat',['O_CREAT',['../group__file__open__constants.html#ga9af988b09d302ec0ae8605d5610e1e9a',1,'Qore']]],
  ['o_5fdirect',['O_DIRECT',['../group__file__open__constants.html#ga682b263ef12018bfd33ca8ba8bc8fd16',1,'Qore']]],
  ['o_5fdirectory',['O_DIRECTORY',['../group__file__open__constants.html#ga5be496ec4bdff357baf0e742139c74b1',1,'Qore']]],
  ['o_5fexcl',['O_EXCL',['../group__file__open__constants.html#ga4ba47557022312d11d81f171fbb2e9ba',1,'Qore']]],
  ['o_5fndelay',['O_NDELAY',['../group__file__open__constants.html#gaef24f5eb3bd3bd4dd9d4658577376715',1,'Qore']]],
  ['o_5fnoctty',['O_NOCTTY',['../group__file__open__constants.html#ga107ba322507fc52fe0c4a6537ded406a',1,'Qore']]],
  ['o_5fnofollow',['O_NOFOLLOW',['../group__file__open__constants.html#ga3452d00ede9696d75d1062d95da9449a',1,'Qore']]],
  ['o_5fnonblock',['O_NONBLOCK',['../group__file__open__constants.html#gad5c43d9d32ea2b08ebbdfe70aa84710a',1,'Qore']]],
  ['o_5frdonly',['O_RDONLY',['../group__file__open__constants.html#ga1ab351549a0b39d1492dc0a48d199f64',1,'Qore']]],
  ['o_5frdwr',['O_RDWR',['../group__file__open__constants.html#ga0d2a9837762a26e27fb666fa44358c37',1,'Qore']]],
  ['o_5fsync',['O_SYNC',['../group__file__open__constants.html#gacb2f3e1944dae38a5c4363ba21bbca11',1,'Qore']]],
  ['o_5ftrunc',['O_TRUNC',['../group__file__open__constants.html#gaeee59f4f7458e6d022dc84da0b9817af',1,'Qore']]],
  ['o_5fwronly',['O_WRONLY',['../group__file__open__constants.html#ga24d94df00b8914ad6459e39cddfe15bf',1,'Qore']]],
  ['object',['Object',['../group__string__type__constants.html#ga470369188279e07c29a3d1fc7b7a3c58',1,'Qore::Type']]],
  ['ocrnl',['OCRNL',['../group__tattr__output__mode__constants.html#gac81628928ae9b55ea854bfd9434f260c',1,'Qore']]],
  ['onlcr',['ONLCR',['../group__tattr__output__mode__constants.html#gaea2c1ed825b301f80a04d159701d5feb',1,'Qore']]],
  ['onlret',['ONLRET',['../group__tattr__output__mode__constants.html#ga63e96508dd0b1895d55501580985b294',1,'Qore']]],
  ['onocr',['ONOCR',['../group__tattr__output__mode__constants.html#ga00759299e93bb514684789a1977f71f4',1,'Qore']]],
  ['onoeot',['ONOEOT',['../group__tattr__output__mode__constants.html#ga1c5645b75037e57d41b0ba8452e8af63',1,'Qore']]],
  ['opost',['OPOST',['../group__tattr__output__mode__constants.html#ga1bff47227b0accb43061f7b7b57dd4fe',1,'Qore']]],
  ['oxtabs',['OXTABS',['../group__tattr__output__mode__constants.html#ga527998ca23a5263066670d3a3109ed67',1,'Qore']]]
];

==> qore-0.8.13.5.tar.bz2: qore-0.8.13.5/docs/lang/html/search/variables_6f.js <==
var searchData=
[
  ['o_5faccmode',['O_ACCMODE',['../group__file__open__constants.html#ga8e48617453f7fd321bcceee8816bf23d',1,'Qore']]],
  ['o_5fappend',['O_APPEND',['../group__file__open__constants.html#gab47c6691139c37e08761a808d16ede1d',1,'Qore']]],
  ['o_5fcreat',['O_CREAT',['../group__file__open__constants.html#ga9af988b09d302ec0ae8605d5610e1e9a',1,'Qore']]],
  ['o_5fdirect',['O_DIRECT',['../group__file__open__constants.html#ga682b263ef12018bfd33ca8ba8bc8fd16',1,'Qore']]],
  ['o_5fdirectory',['O_DIRECTORY',['../group__file__open__constants.html#ga5be496ec4bdff357baf0e742139c74b1',1,'Qore']]],
  ['o_5fexcl',['O_EXCL',['../group__file__open__constants.html#ga4ba47557022312d11d81f171fbb2e9ba',1,'Qore']]],
  ['o_5fndelay',['O_NDELAY',['../group__file__open__constants.html#gaef24f5eb3bd3bd4dd9d4658577376715',1,'Qore']]],
  ['o_5fnoctty',['O_NOCTTY',['../group__file__open__constants.html#ga107ba322507fc52fe0c4a6537ded406a',1,'Qore']]],
  ['o_5fnofollow',['O_NOFOLLOW',['../group__file__open__constants.html#ga3452d00ede9696d75d1062d95da9449a',1,'Qore']]],
  ['o_5fnonblock',['O_NONBLOCK',['../group__file__open__constants.html#gad5c43d9d32ea2b08ebbdfe70aa84710a',1,'Qore']]],
  ['o_5frdonly',['O_RDONLY',['../group__file__open__constants.html#ga1ab351549a0b39d1492dc0a48d199f64',1,'Qore']]],
  ['o_5frdwr',['O_RDWR',['../group__file__open__constants.html#ga0d2a9837762a26e27fb666fa44358c37',1,'Qore']]],
  ['o_5fsync',['O_SYNC',['../group__file__open__constants.html#gacb2f3e1944dae38a5c4363ba21bbca11',1,'Qore']]],
  ['o_5ftrunc',['O_TRUNC',['../group__file__open__constants.html#gaeee59f4f7458e6d022dc84da0b9817af',1,'Qore']]],
  ['o_5fwronly',['O_WRONLY',['../group__file__open__constants.html#ga24d94df00b8914ad6459e39cddfe15bf',1,'Qore']]],
  ['object',['Object',['../group__string__type__constants.html#ga470369188279e07c29a3d1fc7b7a3c58',1,'Qore::Type']]],
  ['ocrnl',['OCRNL',['../group__tattr__output__mode__constants.html#gac81628928ae9b55ea854bfd9434f260c',1,'Qore']]],
  ['offset',['offset',['../struct_qore_1_1_statement_info.html#aae986844e41815e4a12d09a984050aa8',1,'Qore::StatementInfo::offset()'],['../struct_qore_1_1_exception_info.html#a3f928674aa77f0e2a4df65bbed28c80e',1,'Qore::ExceptionInfo::offset()'],['../struct_qore_1_1_call_stack_info.html#a75f754692ac785b55ec4b581c79c3239',1,'Qore::CallStackInfo::offset()']]],
  ['onlcr',['ONLCR',['../group__tattr__output__mode__constants.html#gaea2c1ed825b301f80a04d159701d5feb',1,'Qore']]],
  ['onlret',['ONLRET',['../group__tattr__output__mode__constants.html#ga63e96508dd0b1895d55501580985b294',1,'Qore']]],
  ['onocr',['ONOCR',['../group__tattr__output__mode__constants.html#ga00759299e93bb514684789a1977f71f4',1,'Qore']]],
  ['onoeot',['ONOEOT',['../group__tattr__output__mode__constants.html#ga1c5645b75037e57d41b0ba8452e8af63',1,'Qore']]],
  ['opost',['OPOST',['../group__tattr__output__mode__constants.html#ga1bff47227b0accb43061f7b7b57dd4fe',1,'Qore']]],
  ['oxtabs',['OXTABS',['../group__tattr__output__mode__constants.html#ga527998ca23a5263066670d3a3109ed67',1,'Qore']]]
];
